import React from "react";
import { useTranslation } from "react-i18next";
import {
  InputLabel,
  MenuItem,
  FormControl,
  Select,
  Card,
  CardContent,
  CardActions,
  Button
} from "@material-ui/core";
import { makeStyles } from "@material-ui/core/styles";
import PageTitle from "../../../../components/PageTitle";
import LanguageContainer from "./LanguageContainer";

const useStyles = makeStyles((theme) => ({
  root: {
    minWidth: 275
  },
  formControl: {
    margin: theme.spacing(1),
    minWidth: 300
  }
}));

const AppearancePage = () => {
  const [state, setState] = React.useState({ theme: "default" });

  const { t } = useTranslation();
  const classes = useStyles();

  const handleThemeChange = (event) => {
    const theme = event.target.value;
    setState((prev) => ({ ...prev, theme }));
  };

  return (
    <>
      <PageTitle title={t("Menu.Appearance")} />
      <Card className={classes.root}>
        <CardContent>
          <LanguageContainer />
          <br />
          <FormControl variant="outlined" className={classes.formControl}>
            <InputLabel id="settings.appearance.theme.label">Theme</InputLabel>
            <Select
              labelId="settings.appearance.theme.label"
              id="settings.appearance.theme.select"
              value={state.theme}
              onChange={handleThemeChange}
              label="Theme"
            >
              <MenuItem value="">
                <em>None</em>
              </MenuItem>
              <MenuItem value={"default"}>default</MenuItem>
              <MenuItem value={"dark"}>dark</MenuItem>
              <MenuItem value={"white"}>white</MenuItem>
            </Select>
          </FormControl>
        </CardContent>
        <CardActions>
          <Button size="small">Save</Button>
        </CardActions>
      </Card>
    </>
  );
};

export default AppearancePage;
